<?php
namespace MyMenu\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class FoodMenu
{

    private $crudService;
    private $filesURL;

    public function __construct($crudService, $filesURL)
    {
        $this->crudService = $crudService;
        $this->filesURL = $filesURL;
    }

    // remove baseUrl from imageUrl
    private function sanitizeImageUrl($baseUrl, $imageUrl){
        return str_replace($baseUrl, "", $imageUrl);
    }

    public function getImageFullPath($rows)
    {
        foreach ($rows as &$row) {
            if ($row["IMGSERVICO"] !== null) {
                
                // The point of removing the baseUrl and then concating again
                // is to make sure all images have the same url structure.
                // This is a workarround for the non uniform records in 
                // the database that can have the baseUrl one or multiple times 
                // or have no baseUrl at all.
                $row["IMGSERVICO"] = $this->sanitizeImageUrl($this->filesURL, $row["IMGSERVICO"]);
                
                $row["IMGSERVICO"] = $this->filesURL . $row["IMGSERVICO"];
            }
        }
        return $rows;
    }
    
    public function checkIfIsNotFunction()
    {
        if ((function_exists("gd_info") && gd_info()["JPEG Support"] && function_exists("ImageCreateFromString") && function_exists("ImageSY")
            && function_exists("ImageSX") && function_exists("ImageScale"))) {
            //Is function
            return false;
        }
        //Is not function
        return true;
    }

    public function prepareThumbnailToFront($newImg)
    {
        ob_start();
        imagejpeg($newImg, null, 100);
        $rawImageBytes = ob_get_clean();
        return "data:image/jpeg;base64," . base64_encode($rawImageBytes);
    }

    public function makeThumbnail($url, $filename, $width = 150, $height)
    {
        $image = ImageCreateFromString(file_get_contents($url));
        $height = $height === true ? (ImageSY($image) * $width / ImageSX($image)) : $height;
        $newImage = ImageScale($image, $width, $height);
        return $newImage;
    }

    public function getCardapioPorDia($request, $response)
    {
        try {
            $filter = $request->getFilterCriteria();
            $dataSourceName = 'cardapio_por_dia';
            $filter->setDataSourceName($dataSourceName);
            $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $filter->getConditions());
            $rows = $dataSet->getRows();
            $rows = $this->getImageFullPath($rows);
            // foreach ($rows as &$currServ) {
            //     $oldImg = $currServ['IMGSERVICO'];
            //     if ($this->checkIfIsNotFunction()) {
            //         $currServ['IMGTHUMB'] = $oldImg;
            //     } else if ($oldImg != null) {
            //         $newImg = $this->makeThumbnail($oldImg, null, 350, true);
            //         $currServ['IMGTHUMB'] = $this->prepareThumbnailToFront($newImg);
            //     }
            // }
            $newDataSet = new DataSet($dataSourceName, $rows);
            $response->addDataSet($newDataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
